@@ -1,34 +1,55 @@
 #include <stdlib.h>
-#include <string.h>
+#include <stdio.h>
+#include <unistd.h>
+
+#include "irqbalance.h"
+#include "types.h"
 
 
-#include "prototypes.h"
+char *classes[] = {
+	"other",
+	"legacy",
+	"storage",
+	"timer",
+	"ethernet",
+	"fasteth",
+	0
+};
+
+int map_class_to_level[7] = 
+{ BALANCE_PACKAGE, BALANCE_CACHE, BALANCE_CACHE, BALANCE_NONE, BALANCE_CORE, BALANCE_CORE };
+
+
+int class_counts[7];
 
 /*
+
+NOTE NOTE although that this file has a hard-coded list of modules, something missing is not
+          a big deal; the types are also set based on PCI class information when available.
+
+*/
+
+/*
+
+   Based on the original irqbalance code which is:
+
    Copyright (C) 2003 Red Hat, Inc. All rights reserved.
                                                                                                              
-   Usage and distribution of this file are subject to the Open Software License version 2.1
-   that can be found at http://www.opensource.org/licenses/osl-2.1.txt and the COPYING file as
-   distributed together with this file is included herein by reference. Alternatively you can use 
-   and distribute this file under version 1.1 of the same license.
+   Usage and distribution of this file are subject to the Gnu General Public License Version 2 
+   that can be found at http://www.gnu.org/licenses/gpl.txt and the COPYING file as
+   distributed together with this file is included herein by reference.  
                                                                                                                       
    Author: Arjan van de Ven   <arjanv@redhat.com>
 
 */
 
-/*
- Code to classify the type of irq source based on the strings modules register.
- Evil. Yuck. Ugly. Separated out to a separate file for that reason. Needs rewriting.
- Should probably read a file from disk instead of hardcoded arrays.
- /boot/module-info ?
- */
- 
-
-char *legacy_modules[] = {
+static char *legacy_modules[] = {
  	"PS/2",
  	"serial",
  	"i8042",
  	"acpi",
+	"floppy",
+	"parport",
  	"keyboard",
  	"usb-ohci",
 	"usb-uhci",
@@ -39,28 +60,28 @@ char *legacy_modules[] = {
 	0
 };
 
-char *timer_modules[] = {
+static char *timer_modules[] = {
  	"rtc",
  	"timer",
 	0
 };
 
-char *storage_modules[] = {
+static char *storage_modules[] = {
 	"aic7xxx",
+	"aic79xx",
 	"ide",
 	"cciss",
 	"cpqarray",
 	"qla2",
 	"megaraid",
 	"fusion",
-	"oic",
 	"libata",
 	"ohci1394",
 	"sym53c8xx",
 	0
 };
 
-char *ethernet_modules[] = {
+static char *ethernet_modules[] = {
 	"eth",
 	"e100",
 	"eepro100",
@@ -71,22 +92,14 @@ char *ethernet_modules[] = {
 	0
 };
 
-char *gige_modules[] = {
-	"e1000",
-	"tg3",
-	0
-};
 
-unsigned int class_policy[16];
-
-
-void classify_type(int irqnumber, char *moduletext)
+int find_class(struct interrupt *irq, char *moduletext)
 {
 	int guess = IRQ_OTHER;
 	int i;
 	
 	if (moduletext == NULL)
-		return;
+		return guess;
 		
 	for (i=0; legacy_modules[i]; i++)
 		if (strstr(moduletext, legacy_modules[i]))
@@ -104,12 +117,10 @@ void classify_type(int irqnumber, char *moduletext)
 		if (strstr(moduletext, ethernet_modules[i]))
 			guess = IRQ_ETH;
 
-
-	for (i=0; gige_modules[i]; i++)
-		if (strstr(moduletext, gige_modules[i]))
-			guess = IRQ_GIGE;
+	if (guess == IRQ_OTHER && irq->number==0)
+		guess = IRQ_TIMER;
 	
-	if (guess >  interrupts[irqnumber].type)	
-		interrupts[irqnumber].type = guess;
-
+	if (guess >  irq->class)	
+		return guess;
+        return irq->class;
 }
